import React from 'react';
import PropTypes from 'prop-types';
import ImmutablePropTypes from 'react-immutable-proptypes';
import { Map as Map$1 } from 'immutable';
import { WidgetPreviewContainer } from '@igloo-be/netlify-cms-ui-default';

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

class SelectControl extends React.Component {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "handleChange", e => {
      this.props.onChange(e.target.value);
    });
  }

  render() {
    const _this$props = this.props,
          field = _this$props.field,
          value = _this$props.value,
          forID = _this$props.forID,
          classNameWrapper = _this$props.classNameWrapper,
          setActiveStyle = _this$props.setActiveStyle,
          setInactiveStyle = _this$props.setInactiveStyle;
    const fieldOptions = field.get('options');

    if (!fieldOptions) {
      return React.createElement("div", null, "Error rendering select control for ", field.get('name'), ": No options");
    }

    const options = [...(field.get('default', false) ? [] : [{
      label: '',
      value: ''
    }]), ...fieldOptions.map(option => {
      if (typeof option === 'string') {
        return {
          label: option,
          value: option
        };
      }

      return Map$1.isMap(option) ? option.toJS() : option;
    })];
    return React.createElement("select", {
      id: forID,
      value: value || '',
      onChange: this.handleChange,
      className: classNameWrapper,
      onFocus: setActiveStyle,
      onBlur: setInactiveStyle
    }, options.map((option, idx) => React.createElement("option", {
      key: idx,
      value: option.value
    }, option.label)));
  }

}

_defineProperty(SelectControl, "propTypes", {
  onChange: PropTypes.func.isRequired,
  value: PropTypes.node,
  forID: PropTypes.string.isRequired,
  classNameWrapper: PropTypes.string.isRequired,
  setActiveStyle: PropTypes.func.isRequired,
  setInactiveStyle: PropTypes.func.isRequired,
  field: ImmutablePropTypes.contains({
    options: ImmutablePropTypes.listOf(PropTypes.oneOfType([PropTypes.string, ImmutablePropTypes.contains({
      label: PropTypes.string.isRequired,
      value: PropTypes.string.isRequired
    })])).isRequired
  })
});

_defineProperty(SelectControl, "defaultProps", {
  value: ''
});

const SelectPreview = ({
  value
}) => React.createElement(WidgetPreviewContainer, null, value ? value.toString() : null);

SelectPreview.propTypes = {
  value: PropTypes.string
};

export { SelectControl, SelectPreview };
